import { resolve } from "node:path";
import { environment } from "@config";
import { logger } from "@creations.works/logger";
import { file } from "bun";

const dist = resolve("dist");

Bun.serve({
	port: environment.port,
	hostname: environment.host,
	async fetch(req) {
		const url = new URL(req.url);
		let pathname = decodeURIComponent(url.pathname);
		if (pathname === "/") pathname = "/index.html";

		const filePath = resolve(dist + pathname);
		const bunFile = file(filePath);

		if (await bunFile.exists()) {
			return new Response(bunFile);
		}

		const fallback = file(resolve(dist, "index.html"));
		return new Response(fallback, {
			headers: { "Content-Type": "text/html" },
		});
	},
});

logger.info(`Server running at ${environment.fqdn}`);
